@@ -3,7 +3,7 @@ logging.basicConfig(level=logging.INFO)  # Set level to INFO or higher
 from .ocr_utils import *
 from moviepy import VideoFileClip
 import numpy as np
-from abstract_utilities import eatAll,safe_read_from_json
+from abstract_utilities import eatAll,safe_read_from_json,safe_dump_to_file,eatAll
 from collections import Counter
 # Load spaCy model (run `python -m spacy download en_core_web_sm` first if not installed)
 nlp = spacy.load("en_core_web_sm")
@@ -188,12 +188,14 @@ def derive_all_video_meta(video_path,output_dir=None,video_text_path=None,keywor
         keywords = keywords or info_data.get('context',{}).get('keywords',[])
         description = description or info_data.get('context',{}).get('description','')
         title = title or info_data.get('context',{}).get('title','')
+    if isinstance(keywords,str):
+        keywords = [eatAll(keyword,[' ','#',',','\t']) for keyword in keywords.split(',') if keyword]
     if video_text_path == None:
         text_dir = os.path.join(video_dir,'video_text')
         os.makedirs(text_dir, exist_ok=True)
         video_text_path = os.path.join(text_dir,'video_text.json')
     video_text = analyze_video_text(video_path,output_dir=output_dir)
-    text_constants = get_text_contants(video_text)
+    text_constants = get_text_constants(video_text)
     thumbnail_texts = get_thumbnail_texts(video_dir)
     video_info = derive_video_info(text_constants,keywords,description,title)
     video_json = {"video_file_path":video_path,'thumbnail_texts':thumbnail_texts,"video_info":video_info,"video_text":video_text,"text_contants":text_constants}
